<?php

/**
 * EYEMAGINE - The leading Magento Solution Partner
 *
 * HubSpot Integration with Magento
 *
 * @author    EYEMAGINE <magento@eyemaginetech.com>
 * @copyright Copyright (c) 2016 EYEMAGINE Technology, LLC (http://www.eyemaginetech.com)
 * @license   http://www.eyemaginetech.com/license
 */
namespace Eyemagine\HubSpot\Controller\Sync;

use Magento\Framework\App\Action\Context;
use Eyemagine\HubSpot\Controller\AbstractSync;
use Magento\Framework\Controller\Result\JsonFactory;
use Eyemagine\HubSpot\Helper\Sync as HelperSync;
use Magento\Catalog\Model\ResourceModel\Product\CollectionFactory as ProductCollection;
use Exception;

/**
 * Class GetProducts
 *
 * @package Eyemagine\HubSpot\Controller\Sync
 */
class GetProducts extends AbstractSync
{

    /**
     *
     * @var \Eyemagine\HubSpot\Helper\Sync
     */
    protected $helper;

    /**
     *
     * @var \Magento\Sales\Model\ResourceModel\Order\CollectionFactory
     */
    protected $productCollection;

    /**
     * @param Context $context
     * @param JsonFactory $resultJsonFactory
     * @param HelperSync $helperSync
     * @param ProductCollection $productCollection
     */
    public function __construct(
        Context $context,
        JsonFactory $resultJsonFactory,
        HelperSync $helperSync,
        ProductCollection $productCollection
    ) {
        parent::__construct($context, $resultJsonFactory);

        $this->helper = $helperSync;
        $this->productCollection = $productCollection;
    }

    /**
     * Get products data
     *
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {

        try {
            if (! $this->helper->authenticate()) {
                return $this->outputError($this->helper->getErrorCode(), $this->helper->getErrorMessage(), null);
            }
            $request = $this->getRequest();
            $multistore = $request->getParam('multistore', self::IS_MULTISTORE);
            $start = gmdate('Y-m-d H:i:s', $request->getParam('start', 0));
            $end = gmdate('Y-m-d H:i:s', time() - 300);
            $entityId = $request->getParam('id', '0');
            $maxperpage = $request->getParam('maxperpage', self::MAX_ORDER_PERPAGE);
            $maxAssociated = $request->getParam('maxassoc', self::MAX_ASSOC_PRODUCT_LIMIT);
            $websiteId = $this->helper->getWebsiteId();
            $storeId = $this->helper->getStoreId();
            $stores=$this->helper->getStores();
            $productData = array();

            $productCollection = $this->productCollection->create()
                ->addAttributeToSelect('*')
                ->addFieldToFilter('updated_at', array(
                'from' => $start,
                'to' => $end,
                'date' => true))
                ->addFieldToFilter('entity_id', array(
                    'gt' => $entityId
                ))
                ->setOrder('updated_at', self::SORT_ORDER_ASC)
                ->setOrder('entity_id', self::SORT_ORDER_ASC)
                ->setPageSize($maxperpage);

            if (! ($multistore) && $storeId) {
                $productCollection->addStoreFilter($this->helper->getStore());
            }

            foreach ($productCollection as $item) {
                $product = $this->helper->loadProductCatalogData($item, $storeId, $websiteId, $multistore, $maxAssociated);
                $productData[$product->getId()] = $this->helper->convertAttributeData($product);
            }
        } catch (Exception $e) {
            return $this->outputError(self::ERROR_CODE_UNKNOWN_EXCEPTION, 'Unknown exception on request', $e);
        }

        return $this->outputJson(array(
            'products' => $productData,
            'stores' => $stores,
            'start' => $start
        ));
    }
}
